Learn R Programming

eemR (version 0.1.2)

eem_humification_index: Calculate the fluorescence humification index (HIX)

Description

The fluorescence humification index (HIX), which compares two broad aromatic dominated fluorescence maxima, is calculated at 254 nm excitation by dividing the sum of fluorescence intensities between emission 435 to 480 nm by the the sum of fluorescence intensities between 300 to 345 nm.

Usage

eem_humification_index(eem, scale = FALSE, verbose = TRUE)

Arguments

eem
An object of class eem or eemlist.
scale
Logical indicating if HIX should be scaled, default is FALSE. See details for more information.
verbose
Logical determining if additional messages should be printed.

Value

  • A data frame containing the humification index (HIX) for each eem.

Interpolation

Different excitation and emission wavelenghts are often used to measure EEMs. Hence, it is possible to have mismatchs bewteen measured wavelengths and wavelenghts used to calculate specific metrics. In these circumstances, EEMs are interpolated using the interp2 function from the parcma library. A message warning the user will be prompted if data interpolation is performed.

References

Ohno, T. (2002). Fluorescence Inner-Filtering Correction for Determining the Humification Index of Dissolved Organic Matter. Environmental Science & Technology, 36(4), 742-746.

http://doi.org/10.1021/es0155276

See Also

interp2

Examples

Run this code
file <- system.file("extdata/cary/eem/", package = "eemR")
eem <- eem_read(file)

eem_humification_index(eem)

Run the code above in your browser using DataLab