eem_biological_index: Calculate the biological fluorescence index (BIX)
Description
The biological fluorescence index (BIX) is calculated by
dividing the fluorescence at excitation 310 nm and emission at 380 nm (ex =
310, em = 430) by that at excitation 310 nm and emission at 430 nm (ex =
310, em = 380).
Usage
eem_biological_index(eem, verbose = TRUE)
Arguments
eem
An object of class eem or eemlist.
verbose
Logical determining if additional messages should be printed.
Value
A data frame containing the biological index (BIX) for each eem.
Interpolation
Different excitation and emission wavelenghts are often used to measure
EEMs. Hence, it is possible to have mismatchs bewteen measured wavelengths
and wavelenghts used to calculate specific metrics. In these circumstances,
EEMs are interpolated using the interp2 function from the
parcma library. A message warning the user will be prompted
if data interpolation is performed.
References
Huguet, A., Vacher, L., Relexans, S., Saubusse, S., Froidefond,
J. M., & Parlanti, E. (2009). Properties of fluorescent dissolved organic
matter in the Gironde Estuary. Organic Geochemistry, 40(6), 706-719.