Logical determining if additional messages should be printed.
Value
A data frame containing peaks B, T, A, M and C for each eem.
Interpolation
Different excitation and emission wavelenghts are often used to measure
EEMs. Hence, it is possible to have mismatchs bewteen measured wavelengths
and wavelenghts used to calculate specific metrics. In these circumstances,
EEMs are interpolated using the interp2 function from the
parcma library. A message warning the user will be prompted
if data interpolation is performed.