eem_fluorescence_index: Calculate the fluorescence index (FI)
Description
Calculate the fluorescence index (FI)
Usage
eem_fluorescence_index(eem, verbose = TRUE)
Arguments
eem
An object of class eem
verbose
Logical determining if additional messages should be printed.
Value
A data frame containing fluorescence index (FI) for each eem.
Interpolation
Different excitation and emission wavelenghts are often used to measure
EEMs. Hence, it is possible to have mismatchs bewteen measured wavelengths
and wavelenghts used to calculate specific metrics. In these circumstances,
EEMs are interpolated using the interp2 function from the
parcma library. A message warning the user will be prompted
if data interpolation is performed.